import React from 'react';
import * as PropTypes from 'prop-types';

class NumberFilter extends React.Component {
    state = {
        secondNumBoxShowing: false,
    }

    render() {
        const { secondNumBoxShowing } = this.state;

        const numberStyle = {
            width: 'inherit',
        };

        const selectOptions = [
            {
                value: 'equals',
                caption: 'Equals',
            },
            {
                value: 'greaterThan',
                caption: 'Greater than',
            },
            {
                value: 'lessThan',
                caption: 'Less than',
            },
            {
                value: 'notEqual',
                caption: 'Not equal',
            },
            {
                value: 'inRange',
                caption: 'In range',
            },
        ];

        const {
            width,
            placeholder,
            textBoxes,
            selectedFilterOption,
            filterStyle,
            selectStyles,
            field,
        } = this.props;

        return (
            <div style={ {
                width,
                ...filterStyle,
            } }>
                { /* eslint-disable-next-line jsx-a11y/no-onchange */ }
                <select
                    onChange={ this.handleSelectChange }
                    style={ selectStyles }
                    className="ag-filter-select"
                    value={ selectedFilterOption[field] }
                    ref={ (ref) => this.numSelect = ref }>
                    { selectOptions.map((option) => (
                        <option
                            key={ `${field}__${option.value}` }
                            value={ option.value }>
                            { option.caption }
                        </option>
                    )) }
                </select>
                <input
                    onChange={ this.handleNumChange }
                    ref={ (num) => { this.num = num ; } }
                    placeholder={ placeholder }
                    style={ numberStyle }
                    type="number"
                    value={ textBoxes[field].num || 0 } />
                {
                    (secondNumBoxShowing || selectedFilterOption[field] === 'inRange') ?
                        <input
                            onChange={ this.handleNumChange }
                            ref={ (num) => { this.num2 = num ; } }
                            placeholder={ placeholder }
                            style={ {
                                marginTop: '2px',
                                ...numberStyle,
                            } }
                            type="number"
                            value={ textBoxes[field].num2 || 0 } />
                        :
                        null
                }
            </div>
        );
    }

    /**
     * Handles change on filter option
     */
    handleSelectChange = () => {
        this.setState({ secondNumBoxShowing: this.numSelect.value === 'inRange' });
        this.handleNumChange();
    }

    /**
     * Handles change in number filter text.
     */
    handleNumChange = () => {
        const {
            field,
            onNumChanged,
        } = this.props;

        const {
            secondNumBoxShowing,
        } = this.state;

        const num = isNaN(parseInt(this.num.value)) ? 0 : parseInt(this.num.value);
        const num2 = secondNumBoxShowing ? parseInt(this.num2.value) : 0;

        const textBoxes = {
            [field]: {
                num,
                num2: isNaN(num2) ? 0 : num2,
            },
        };

        if (onNumChanged) {
            onNumChanged(field, textBoxes, this.numSelect.value);
        }
    };
};

NumberFilter.propTypes = {
    /** Column width */
    width: PropTypes.string,

    /** Column identifier (field name) */
    field: PropTypes.string,

    /** Filter text values for each field/column */
    textBoxes: PropTypes.object,

    /** Selected filter option, e.g. contains, equals etc. */
    selectedFilterOption: PropTypes.object,

    /** Passes on changed value */
    onNumChanged: PropTypes.func,

    /** Style for the filter */
    filterStyle: PropTypes.object,

    /** Style for select element */
    selectStyles: PropTypes.object,

    /** Placeholder string for number input field. */
    placeholder: PropTypes.string,
};

export default NumberFilter;
